@@ -86,14 +86,14 @@ where
         self.parse()
     }
 
-    fn parse_id(&mut self) -> PResult<Text> {
+    fn parse_id(&mut self) -> PResult<Ident> {
         let span = self.input.cur_span()?;
         if !is!(self, Ident) {
             return Err(Error::new(span, ErrorKind::Expected("Ident")));
         }
 
         match bump!(self) {
-            Token::Ident { value, raw } => Ok(Text { span, value, raw }),
+            Token::Ident { value, raw } => Ok(Ident { span, value, raw }),
             _ => {
                 unreachable!()
             }
